@@ -13,6 +13,7 @@ from urllib.parse import urlparse
 import requests
 from cookiecutter.main import cookiecutter
 from cookiecutter.repository import is_repo_url
+from platformdirs import PlatformDirs
 
 try:
     import tomllib
@@ -26,6 +27,7 @@ from briefcase.exceptions import (
     BadNetworkResourceError,
     BriefcaseCommandError,
     BriefcaseConfigError,
+    InfoHelpText,
     MissingNetworkResourceError,
 )
 from briefcase.integrations.subprocess import Subprocess
@@ -112,20 +114,75 @@ class BaseCommand(ABC):
     GLOBAL_CONFIG_CLASS = GlobalConfig
     APP_CONFIG_CLASS = AppConfig
 
-    def __init__(self, base_path, home_path=Path.home(), apps=None, input_enabled=True):
-        self.base_path = base_path
-        self.home_path = home_path
-        self.dot_briefcase_path = home_path / ".briefcase"
-        self.tools_path = self.dot_briefcase_path / "tools"
+    def __init__(
+        self,
+        base_path,
+        home_path=None,
+        data_path=None,
+        apps=None,
+        input_enabled=True,
+    ):
+        # Some details about the host machine
+        self.host_arch = platform.machine()
+        self.host_os = platform.system()
+
+        self.base_path = Path(base_path)
+
+        # If a home path is provided during construction, use it. This usually
+        # indicates we're under test conditions.
+        if home_path is None:
+            home_path = Path.home()
+        self.home_path = Path(home_path)
+
+        # If a data path is provided during construction, use it. This usually
+        # indicates we're under test conditions. If there's no data path
+        # provided, look for a BRIEFCASE_HOME environment variable. If that
+        # isn't defined, use a platform-specific default data path.
+        if data_path is None:
+            try:
+                briefcase_home = os.environ["BRIEFCASE_HOME"]
+                data_path = Path(briefcase_home).resolve()
+                # Path("") converts to ".", so check for that edge case.
+                if briefcase_home == "" or not data_path.exists():
+                    raise BriefcaseCommandError(
+                        "The path specified by BRIEFCASE_HOME does not exist."
+                    )
+            except KeyError:
+                if self.host_os == "Darwin":
+                    # macOS uses a bundle name, rather than just the app name
+                    app_name = "org.beeware.briefcase"
+                else:
+                    app_name = "briefcase"
+
+                data_path = PlatformDirs(
+                    appname=app_name,
+                    appauthor="BeeWare",
+                ).user_cache_path
+
+        if " " in os.fsdecode(data_path):
+            raise BriefcaseCommandError(
+                f"""
+The location Briefcase will use to store tools and support files:
+
+    {data_path}
+
+contains spaces. This will cause problems with some tools, preventing
+you from building and packaging applications.
+
+You can set the environment variable BRIEFCASE_HOME to specify
+a custom location for Briefcase's tools.
+
+"""
+            )
+
+        self.data_path = Path(data_path)
+
+        self.tools_path = self.data_path / "tools"
 
         self.global_config = None
         self.apps = {} if apps is None else apps
         self._path_index = {}
 
-        # Some details about the host machine
-        self.host_arch = platform.machine()
-        self.host_os = platform.system()
-
         # External service APIs.
         # These are abstracted to enable testing without patching.
         self.cookiecutter = cookiecutter
@@ -133,6 +190,7 @@ class BaseCommand(ABC):
         self.input = Console(enabled=input_enabled)
         self.os = os
         self.sys = sys
+        self.stdlib_platform = platform
         self.shutil = shutil
         self.subprocess = Subprocess(self)
 
@@ -143,6 +201,86 @@ class BaseCommand(ABC):
         self.logger = Log()
         self.save_log = False
 
+    def check_obsolete_data_dir(self):
+        """Inform user if obsolete data directory exists.
+
+        TODO: Remove this check after 1 JAN 2023 since most users will have transitioned by then
+
+        Previous versions used the ~/.briefcase directory to store
+        downloads, tools, etc. This check lets users know the old
+        directory still exists and their options to migrate or clean up.
+        """
+        dot_briefcase_path = self.home_path / ".briefcase"
+
+        # If there's no .briefcase path, no need to check for migration.
+        if not dot_briefcase_path.exists():
+            return
+
+        # If the data path is user-provided, don't check for migration.
+        if "BRIEFCASE_HOME" in os.environ:
+            return
+
+        if self.data_path.exists():
+            self.logger.warning(
+                f"""\
+Briefcase is no longer using the data directory:
+
+    {dot_briefcase_path}
+
+This directory can be safely deleted.
+"""
+            )
+        else:
+            self.logger.warning(
+                f"""\
+*************************************************************************
+** NOTICE: Briefcase is changing its data directory                   **
+*************************************************************************
+
+    Briefcase is moving its data directory from:
+
+        {dot_briefcase_path}
+
+    to:
+
+        {self.data_path}
+
+    If you continue, Briefcase will re-download the tools and data it
+    uses to build and package applications.
+
+    To avoid potentially large downloads and long installations, you
+    can manually move the old data directory to the new location.
+
+    If you continue and allow Briefcase to re-download its tools, the
+    old data directory can be safely deleted.
+
+*************************************************************************
+"""
+            )
+            self.input.prompt()
+            if not self.input.boolean_input(
+                "Do you want to re-download the Briefcase support tools",
+                # Default to continuing for non-interactive runs
+                default=not self.input.enabled,
+            ):
+                raise InfoHelpText(
+                    f"""\
+Move the Briefcase data directory from:
+
+    {dot_briefcase_path}
+
+to:
+
+    {self.data_path}
+
+or delete the old data directory, and re-run Briefcase.
+
+"""
+                )
+
+            # Create data directory to prevent full notice showing again.
+            self.data_path.mkdir(parents=True, exist_ok=True)
+
     @property
     def create_command(self):
         """Factory property; return an instance of a create command for the
@@ -291,6 +429,20 @@ class BaseCommand(ABC):
             path_index = self._load_path_index(app)
         return self.bundle_path(app) / path_index["support_path"]
 
+    def app_requirements_path(self, app: BaseConfig):
+        """Obtain the path into which a requirements.txt file should be
+        written.
+
+        :param app: The config object for the app
+        :return: The full path where the requirements.txt file should be written
+        """
+        # If the index file hasn't been loaded for this app, load it.
+        try:
+            path_index = self._path_index[app]
+        except KeyError:
+            path_index = self._load_path_index(app)
+        return self.bundle_path(app) / path_index["app_requirements_path"]
+
     def app_packages_path(self, app: BaseConfig):
         """Obtain the path into which dependencies should be installed.
 
@@ -459,7 +611,9 @@ class BaseCommand(ABC):
                     )
 
         except FileNotFoundError as e:
-            raise BriefcaseConfigError("configuration file not found") from e
+            raise BriefcaseConfigError(
+                f"""Configuration file not found. Did you run briefcase in the directory that contains {filename!r}?"""
+            ) from e
 
     def download_url(self, url, download_path):
         """Download a given URL, caching it. If it has already been downloaded,
