@@ -1,4 +1,6 @@
+import hashlib
 import os
+import platform
 import shutil
 import subprocess
 import sys
@@ -258,6 +260,8 @@ class CreateCommand(BaseCommand):
         # Augment with some extra fields.
         extra_context.update(
             {
+                # Properties of the generating environment
+                "python_version": platform.python_version(),
                 # Transformations of explicit properties into useful forms
                 "module_name": app.module_name,
                 "package_name": app.package_name,
@@ -294,11 +298,36 @@ class CreateCommand(BaseCommand):
             # Branch does not exist for python version
             raise TemplateUnsupportedVersion(app.template_branch) from e
 
+    def _unpack_support_package(self, support_file_path, support_path):
+        """Unpack a support package into a specific location.
+
+        :param support_file_path: The path to the support file to be unpacked.
+        :param support_path: The path where support files should unpacked.
+        """
+        try:
+            with self.input.wait_bar("Unpacking support package..."):
+                support_path.mkdir(parents=True, exist_ok=True)
+                self.shutil.unpack_archive(
+                    support_file_path,
+                    extract_dir=support_path,
+                )
+        except (shutil.ReadError, EOFError) as e:
+            raise InvalidSupportPackage(support_file_path) from e
+
     def install_app_support_package(self, app: BaseConfig):
         """Install the application support package.
 
         :param app: The config object for the app
         """
+        try:
+            support_path = self.support_path(app)
+        except KeyError:
+            self.logger.info("No support package required.")
+        else:
+            support_file_path = self._download_support_package(app)
+            self._unpack_support_package(support_file_path, support_path)
+
+    def _download_support_package(self, app):
         try:
             # Work out if the app defines a custom override for
             # the support package URL.
@@ -329,14 +358,29 @@ class CreateCommand(BaseCommand):
                     # No support revision specified.
                     self.logger.info("... using most recent revision")
 
+                if custom_support_package:
+                    # If the support package is custom, cache it using a hash of
+                    # the download URL. This is needed to differentiate to support
+                    # packages with the same filename, served at different URLs.
+                    # (or a custom package that collides with an official package name)
+                    download_path = (
+                        self.data_path
+                        / "support"
+                        / hashlib.sha256(
+                            support_package_url.encode("utf-8")
+                        ).hexdigest()
+                    )
+                else:
+                    download_path = self.data_path / "support"
+
                 # Download the support file, caching the result
                 # in the user's briefcase support cache directory.
-                support_filename = self.download_url(
+                return self.download_url(
                     url=support_package_url,
-                    download_path=self.dot_briefcase_path / "support",
+                    download_path=download_path,
                 )
             else:
-                support_filename = Path(support_package_url)
+                return Path(support_package_url)
         except MissingNetworkResourceError as e:
             # If there is a custom support package, report the missing resource as-is.
             if custom_support_package:
@@ -349,29 +393,46 @@ class CreateCommand(BaseCommand):
 
         except requests_exceptions.ConnectionError as e:
             raise NetworkFailure("downloading support package") from e
-        try:
-            with self.input.wait_bar("Unpacking support package..."):
-                support_path = self.support_path(app)
-                support_path.mkdir(parents=True, exist_ok=True)
-                # TODO: Py3.6 compatibility; os.fsdecode not required in Py3.7
-                self.shutil.unpack_archive(
-                    os.fsdecode(support_filename), extract_dir=os.fsdecode(support_path)
-                )
-        except (shutil.ReadError, EOFError) as e:
-            raise InvalidSupportPackage(support_package_url) from e
 
-    def install_app_dependencies(self, app: BaseConfig):
-        """Install the dependencies for the app.
+    def _write_requirements_file(self, app: BaseConfig, requirements_path):
+        """Configure application dependencies by writing a requirements.txt
+        file.
 
-        :param app: The config object for the app
+        :param app: The app configuration
+        :param requirements_path: The full path to a requirements.txt file that
+            will be written.
         """
+        # Windows allows both / and \ as a path separator in requirements.
+        separators = [os.sep]
+        if os.altsep:
+            separators.append(os.altsep)
 
-        target = self.app_packages_path(app)
+        with self.input.wait_bar("Writing requirements file..."):
+            with (requirements_path).open("w", encoding="utf-8") as f:
+                if app.requires:
+                    for requirement in app.requires:
+                        # If the requirement is a local path, convert it to
+                        # absolute, because Flatpak moves the requirements file
+                        # to a different place before using it.
+                        if any(sep in requirement for sep in separators) and (
+                            not _has_url(requirement)
+                        ):
+                            # We use os.path.abspath() rather than Path.resolve()
+                            # because we *don't* want Path's symlink resolving behavior.
+                            requirement = os.path.abspath(self.base_path / requirement)
+                        f.write(f"{requirement}\n")
 
+    def _install_app_dependencies(self, app: BaseConfig, app_packages_path):
+        """Install dependencies for the app with pip.
+
+        :param app: The app configuration
+        :param app_packages_path: The full path of the app_packages folder into which
+            dependencies should be installed.
+        """
         # Clear existing dependency directory
-        if target.is_dir():
-            self.shutil.rmtree(target)
-            self.os.mkdir(target)
+        if app_packages_path.is_dir():
+            self.shutil.rmtree(app_packages_path)
+            self.os.mkdir(app_packages_path)
 
         # Install dependencies
         if app.requires:
@@ -385,9 +446,7 @@ class CreateCommand(BaseCommand):
                             "install",
                             "--upgrade",
                             "--no-user",
-                            "--progress-bar",
-                            "off",
-                            f"--target={target}",
+                            f"--target={app_packages_path}",
                         ]
                         + app.requires,
                         check=True,
@@ -397,6 +456,33 @@ class CreateCommand(BaseCommand):
         else:
             self.logger.info("No application dependencies.")
 
+    def install_app_dependencies(self, app: BaseConfig):
+        """Handle dependencies for the app.
+
+        This will result in either (in preferential order):
+         * a requirements.txt file being written at a location specified by
+           ``app_requirements_path`` in the template path index
+         * dependencies being installed with pip into the location specified
+           by the ``app_packages_path`` in the template path index.
+
+        If the path index doesn't specify either of the path index entries,
+        an error is raised.
+
+        :param app: The config object for the app
+        """
+        try:
+            path = self.app_requirements_path(app)
+            self._write_requirements_file(app, path)
+        except KeyError:
+            try:
+                path = self.app_packages_path(app)
+                self._install_app_dependencies(app, path)
+            except KeyError as e:
+                raise BriefcaseCommandError(
+                    "Application path index file does not define "
+                    "`app_requirements_path` or `app_packages_path`"
+                ) from e
+
     def install_app_code(self, app: BaseConfig):
         """Install the application code into the bundle.
 
@@ -623,3 +709,18 @@ class CreateCommand(BaseCommand):
                 state = self.create_app(app, **full_options(state, options))
 
         return state
+
+
+# Detects any of the URL schemes supported by pip
+# (https://pip.pypa.io/en/stable/topics/vcs-support/).
+def _has_url(requirement):
+    return any(
+        f"{scheme}:" in requirement
+        for scheme in (
+            ["http", "https", "file", "ftp"]
+            + ["git+file", "git+https", "git+ssh", "git+http", "git+git", "git"]
+            + ["hg+file", "hg+http", "hg+https", "hg+ssh", "hg+static-http"]
+            + ["svn", "svn+svn", "svn+http", "svn+https", "svn+ssh"]
+            + ["bzr+http", "bzr+https", "bzr+ssh", "bzr+sftp", "bzr+ftp", "bzr+lp"]
+        )
+    )
