@@ -55,7 +55,9 @@ class Printer:
     """Interface for printing and managing output to the console and/or log."""
 
     # Console to manage console output.
-    console = RichConsole(highlighter=RichConsoleHighlighter(), emoji=False)
+    console = RichConsole(
+        highlighter=RichConsoleHighlighter(), emoji=False, soft_wrap=True
+    )
 
     # Console to record all logging to a buffer while not printing anything to the console.
     # We need to be wide enough to render `sdkmanager --list_installed` output without
@@ -273,9 +275,10 @@ class Console:
         self.print = printer
         self.input = printer.console.input
         self.enabled = enabled
+        self._wait_bar: Progress = None
         # Signal that Rich is dynamically controlling the console output.
         # Therefore, all output must be printed to the screen by Rich to
-        # prevent corruption of dynamic elements like Wait Bars.
+        # prevent corruption of dynamic elements like the Wait Bar.
         self.is_output_controlled = False
 
     def prompt(self, *values, markup=False, **kwargs):
@@ -308,28 +311,38 @@ class Console:
         transient=False,
         markup=False,
     ):
-        """Returns a wait bar as a context manager.
+        """Activates the Wait Bar as a context manager.
 
-        :param message: text explaining what is being awaited
+        If the Wait Bar is already active, then its message is updated for the new
+        context. Once the new context is complete, the previous Wait Bar message
+        is restored.
+
+        :param message: text explaining what is being awaited; should end in '...'
         :param done_message: text appended to the message after exiting
         :param transient: if True, remove bar and message from screen after exiting;
             if False (default), the message will remain on the screen without pulsing bar.
         :param markup: whether to interpret Rich styling markup in the message; if True,
             the message must already be escaped; defaults False.
         """
-        wait_bar = Progress(
-            TextColumn("    "),
-            BarColumn(bar_width=20, style="black", pulse_style="white"),
-            TextColumn(message),
-            transient=True,
-            console=self.print.console,
-        )
-        # setting start=False causes the progress bar to pulse
-        wait_bar.add_task("", start=False)
+        if self._wait_bar is None:
+            self._wait_bar = Progress(
+                TextColumn("    "),
+                BarColumn(bar_width=20, style="black", pulse_style="white"),
+                TextColumn("{task.fields[message]}"),
+                transient=True,
+                console=self.print.console,
+            )
+            # start=False causes the progress bar to "pulse"
+            # message=None is a sentinel the Wait Bar should be inactive
+            self._wait_bar.add_task("", start=False, message=None)
+
+        self.is_output_controlled = True
+        wait_bar_task = self._wait_bar.tasks[0]
+        previous_message = wait_bar_task.fields["message"]
+        self._wait_bar.update(wait_bar_task.id, message=message)
         try:
-            self.is_output_controlled = True
-            with wait_bar:
-                yield
+            self._wait_bar.start()
+            yield
         except BaseException:
             # ensure the message is left on the screen even if user sends CTRL+C
             if message and not transient:
@@ -337,12 +350,13 @@ class Console:
             raise
         else:
             if message and not transient:
-                self.print(
-                    f'{message}{f" {done_message}" if done_message else ""}',
-                    markup=markup,
-                )
+                self.print(f"{message} {done_message}", markup=markup)
         finally:
-            self.is_output_controlled = False
+            self._wait_bar.update(wait_bar_task.id, message=previous_message)
+            # Deactivate the Wait Bar if returning to its initial state
+            if previous_message is None:
+                self._wait_bar.stop()
+                self.is_output_controlled = False
 
     def boolean_input(self, question, default=False):
         """Get a boolean input from user, in the form of y/n.
@@ -439,6 +453,7 @@ class Console:
             raise InputDisabled()
         try:
             input_value = self.input(prompt, markup=markup)
+            self.print.to_log(prompt)
             self.print.to_log(f"{Log.DEBUG_PREFACE}User input: {input_value}")
             return input_value
         except EOFError:
