@@ -3,6 +3,7 @@ import re
 import shutil
 import subprocess
 import time
+from contextlib import suppress
 from pathlib import Path
 
 from requests import exceptions as requests_exceptions
@@ -1004,7 +1005,8 @@ In future, you can specify this device by running:
             ],
             env=self.env,
             stdout=subprocess.PIPE,
-            stderr=subprocess.PIPE,
+            stderr=subprocess.STDOUT,
+            bufsize=1,
             start_new_session=True,
         )
 
@@ -1013,55 +1015,17 @@ In future, you can specify this device by running:
         # not ready until the boot process has finished. To determine
         # the boot status, we need the device ID, and an ADB connection.
 
-        # Step 1: Wait for the device to appear so we can get an
+        # Phase 1: Wait for the device to appear so we can get an
         # ADB instance for the new device.
-        with self.command.input.wait_bar("Starting emulator..."):
-            adb = None
-            known_devices = set()
-            while adb is None:
-                if emulator_popen.poll() is not None:
-                    raise BriefcaseCommandError(
-                        f"""\
-Android emulator was unable to start!
-
-Try starting the emulator manually by running:
-
-    $ {' '.join(str(arg) for arg in emulator_popen.args)}
-
-Resolve any problems you discover, then try running your app again. You may
-find this page helpful in diagnosing emulator problems.
-
-    https://developer.android.com/studio/run/emulator-acceleration#accel-vm
-"""
-                    )
-
-                for device, details in sorted(self.devices().items()):
-                    # Only process authorized devices that we haven't seen.
-                    if details["authorized"] and device not in known_devices:
-                        adb = self.adb(device)
-                        device_avd = adb.avd_name()
-
-                        if device_avd == avd:
-                            # Found an active device that matches
-                            # the AVD we are starting.
-                            full_name = f"@{avd} (running emulator)"
-                            break
-                        else:
-                            # Not the one. Zathras knows.
-                            adb = None
-                            known_devices.add(device)
-
-                # Try again in 2 seconds...
-                self.sleep(2)
-
-        # Phase 2: Wait for the boot process to complete
-        if not adb.has_booted():
-            with self.command.input.wait_bar("Booting emulator..."):
-                while not adb.has_booted():
+        try:
+            with self.command.input.wait_bar("Starting emulator..."):
+                adb = None
+                known_devices = set()
+                while adb is None:
                     if emulator_popen.poll() is not None:
                         raise BriefcaseCommandError(
                             f"""\
-Android emulator was unable to boot!
+Android emulator was unable to start!
 
 Try starting the emulator manually by running:
 
@@ -1074,9 +1038,54 @@ find this page helpful in diagnosing emulator problems.
 """
                         )
 
+                    for device, details in sorted(self.devices().items()):
+                        # Only process authorized devices that we haven't seen.
+                        if details["authorized"] and device not in known_devices:
+                            adb = self.adb(device)
+                            device_avd = adb.avd_name()
+
+                            if device_avd == avd:
+                                # Found an active device that matches
+                                # the AVD we are starting.
+                                full_name = f"@{avd} (running emulator)"
+                                break
+                            else:
+                                # Not the one. Zathras knows.
+                                adb = None
+                                known_devices.add(device)
+
                     # Try again in 2 seconds...
                     self.sleep(2)
 
+            # Phase 2: Wait for the boot process to complete
+            if not adb.has_booted():
+                with self.command.input.wait_bar("Booting emulator..."):
+                    while not adb.has_booted():
+                        if emulator_popen.poll() is not None:
+                            raise BriefcaseCommandError(
+                                f"""\
+Android emulator was unable to boot!
+
+Try starting the emulator manually by running:
+
+    $ {' '.join(str(arg) for arg in emulator_popen.args)}
+
+Resolve any problems you discover, then try running your app again. You may
+find this page helpful in diagnosing emulator problems.
+
+    https://developer.android.com/studio/run/emulator-acceleration#accel-vm
+"""
+                            )
+
+                        # Try again in 2 seconds...
+                        self.sleep(2)
+        except Exception:
+            # if the emulator exited, this should return its output immediately;
+            # if it is still running, this will quickly time out and print nothing.
+            with suppress(subprocess.TimeoutExpired):
+                self.command.logger.info(emulator_popen.communicate(timeout=1)[0])
+            raise
+
         # Return the device ID and full name.
         return device, full_name
 
@@ -1235,18 +1244,7 @@ Activity class not found while starting app.
                 f"Unable to start {package}/{activity} on {self.device}"
             ) from e
 
-    def clear_log(self):
-        """Clear the log for the device.
-
-        Returns `None` on success; raises an exception on failure.
-        """
-        try:
-            # Invoke `adb logcat -c`
-            self.run("logcat", "-c")
-        except subprocess.CalledProcessError as e:
-            raise BriefcaseCommandError(f"Unable to clear log on {self.device}") from e
-
-    def logcat(self):
+    def logcat(self, pid):
         """Start tailing the adb log for the device."""
         try:
             # stream output so it's captured in logging
@@ -1256,11 +1254,11 @@ Activity class not found while starting app.
                     "-s",
                     self.device,
                     "logcat",
-                    "-s",
-                    "MainActivity:*",
-                    "stdio:*",
-                    "Python:*",
-                ],
+                    "--pid",  # This option is available since API level 24.
+                    pid,
+                ]
+                # Filter out some noisy and useless tags.
+                + [f"{tag}:S" for tag in ["EGL_emulation"]],
                 env=self.android_sdk.env,
                 check=True,
                 stream_output=True,
@@ -1272,3 +1270,15 @@ Activity class not found while starting app.
             # Exit normally since the user was instructed to use CTRL+C.
             if e.returncode not in {-2, 0xC000013A}:
                 raise BriefcaseCommandError("Error starting ADB logcat.") from e
+
+    def pidof(self, package):
+        """Return the PID of the given app as a string, or None if it isn't
+        running."""
+        # The pidof command is available since API level 24. The level 23 emulator image also
+        # includes it, but it doesn't work correctly (it returns all processes).
+        try:
+            # Exit status is unreliable: some devices (e.g. Nexus 4) return 0 even when no
+            # process was found.
+            return self.run("shell", "pidof", "-s", package).strip() or None
+        except subprocess.CalledProcessError:
+            return None
