@@ -94,7 +94,7 @@ Visit:
 
     {install_url}
 
-to download and install git manually.
+to download and install Docker manually.
 {extra_content}
 If you have installed Docker recently and are still getting this error, you may
 need to restart your terminal session.
@@ -199,17 +199,23 @@ class Docker:
         self._subprocess = command.subprocess
         self.app = app
 
+    @property
+    def docker_data_path(self):
+        """The briefcase data directory used inside container."""
+        return "/home/brutus/.cache/briefcase"
+
     def prepare(self):
         try:
             self.command.logger.info(
-                "Building Docker container image...", prefix=self.app.app_name
+                "Building Docker container image...",
+                prefix=self.app.app_name,
             )
             try:
                 system_requires = " ".join(self.app.system_requires)
             except AttributeError:
                 system_requires = ""
 
-            with self.command.input.wait_bar("Building container..."):
+            with self.command.input.wait_bar("Building Docker image..."):
                 self._subprocess.run(
                     [
                         "docker",
@@ -237,58 +243,85 @@ class Docker:
                 )
         except subprocess.CalledProcessError as e:
             raise BriefcaseCommandError(
-                f"Error building Docker container for {self.app.app_name}."
+                f"Error building Docker image for {self.app.app_name}."
             ) from e
 
-    def run(self, args, env=None, **kwargs):
-        """Run a process inside the Docker container."""
-        # Set up the `docker run` invocation in interactive mode,
-        # with volume mounts for the platform and .briefcase directories.
-        # The :z suffix allows SELinux to modify the host mount; it is ignored
-        # on non-SELinux platforms.
+    def _dockerize_path(self, arg):
+        """Relocate any local path into the equivalent location on the docker
+        filesystem.
+
+        Converts:
+        * any reference to sys.executable into the python executable in the docker container
+        * any path in <platform path> into the equivalent stemming from /app
+        * any path in <data path> into the equivalent in ~/.cache/briefcase
+
+        :param arg: The string argument to convert to dockerized paths
+        :returns: A string where all convertible paths have been replaced.
+        """
+        if arg == sys.executable:
+            return f"python{self.command.python_version_tag}"
+        arg = arg.replace(os.fsdecode(self.command.platform_path), "/app")
+        arg = arg.replace(os.fsdecode(self.command.data_path), self.docker_data_path)
+
+        return arg
+
+    def _dockerize_args(self, args, env=None):
+        """Convert arguments and environment into a Docker-compatible form.
+        Convert an argument and environment specifiation into a form that can
+        be used as arguments to invoke Docker. This involves:
+
+         * Configuring the Docker invocation to reference the
+           appropriate container image, and clean up afterwards
+         * Setting volume mounts for the container instance
+         * Transforming any references to local paths into Docker path references.
+
+        :param args: The arguments for the command to be invoked
+        :param env: The environment specification for the command to be executed
+        :returns: A list of arguments that can be used to invoke the command
+            inside a docker container.
+        """
+        # The :z suffix on volument mounts allows SELinux to modify the host
+        # mount; it is ignored on non-SELinux platforms.
         docker_args = [
             "docker",
             "run",
-            "--tty",
             "--volume",
             f"{self.command.platform_path}:/app:z",
             "--volume",
-            f"{self.command.dot_briefcase_path}:/home/brutus/.briefcase:z",
+            f"{self.command.data_path}:{self.docker_data_path}:z",
+            "--rm",
         ]
 
         # If any environment variables have been defined, pass them in
         # as --env arguments to Docker.
         if env:
             for key, value in env.items():
-                docker_args.extend(["--env", f"{key}={value}"])
+                docker_args.extend(["--env", f"{key}={self._dockerize_path(value)}"])
 
-        # ... then the image name.
+        # ... then the image name to create the temporary container with
         docker_args.append(self.command.docker_image_tag(self.app))
 
-        # ... then add all the arguments
-        for arg in args:
-            arg = str(arg)
-            if arg == sys.executable:
-                docker_args.append(f"python{self.command.python_version_tag}")
-            elif os.fsdecode(self.command.platform_path) in arg:
-                docker_args.append(
-                    arg.replace(os.fsdecode(self.command.platform_path), "/app")
-                )
-            elif os.fsdecode(self.command.dot_briefcase_path) in arg:
-                docker_args.append(
-                    arg.replace(
-                        os.fsdecode(self.command.dot_briefcase_path),
-                        "/home/brutus/.briefcase",
-                    )
-                )
-            else:
-                docker_args.append(arg)
+        # ... then add the command (and its arguments) to run in the container
+        docker_args.extend([self._dockerize_path(str(arg)) for arg in args])
 
-        # Invoke the process.
+        return docker_args
+
+    def run(self, args, env=None, **kwargs):
+        """Run a process inside a Docker container."""
         # Any exceptions from running the process are *not* caught.
         # This ensures that "docker.run()" behaves as closely to
         # "subprocess.run()" as possible.
         self._subprocess.run(
-            docker_args,
+            self._dockerize_args(args, env=env),
+            **kwargs,
+        )
+
+    def check_output(self, args, env=None, **kwargs):
+        """Run a process inside a Docker container, capturing output."""
+        # Any exceptions from running the process are *not* caught.
+        # This ensures that "docker.check_output()" behaves as closely to
+        # "subprocess.check_output()" as possible.
+        return self._subprocess.check_output(
+            self._dockerize_args(args, env=env),
             **kwargs,
         )
