@@ -6,6 +6,7 @@ import subprocess
 import sys
 import threading
 import time
+from pathlib import Path
 
 import psutil
 
@@ -217,6 +218,7 @@ class Subprocess:
 
         # Otherwise, invoke run() normally.
         self._log_command(args)
+        self._log_cwd(kwargs.get("cwd"))
         self._log_environment(kwargs.get("env"))
 
         try:
@@ -266,6 +268,8 @@ class Subprocess:
         kwargs["stdout"] = subprocess.PIPE
         # if stderr isn't explicitly redirected, then send it to stdout.
         kwargs.setdefault("stderr", subprocess.STDOUT)
+        # use line-buffered output by default
+        kwargs.setdefault("bufsize", 1)
 
         stderr = None
         with self.Popen(args, **kwargs) as process:
@@ -273,6 +277,7 @@ class Subprocess:
             if process.stderr and kwargs["stderr"] != subprocess.STDOUT:
                 stderr = process.stderr.read()
             return_code = process.poll()
+        self._log_return_code(return_code)
 
         if check and return_code:
             raise subprocess.CalledProcessError(return_code, args, stderr=stderr)
@@ -291,6 +296,7 @@ class Subprocess:
            is returned as strings instead of bytes.
         """
         self._log_command(args)
+        self._log_cwd(kwargs.get("cwd"))
         self._log_environment(kwargs.get("env"))
 
         try:
@@ -355,13 +361,14 @@ class Subprocess:
            is returned as strings instead of bytes.
         """
         self._log_command(args)
+        self._log_cwd(kwargs.get("cwd"))
         self._log_environment(kwargs.get("env"))
 
         return self._subprocess.Popen(
             [str(arg) for arg in args], **self.final_kwargs(**kwargs)
         )
 
-    def stream_output(self, label, popen_process, stop_func=None):
+    def stream_output(self, label, popen_process, stop_func=lambda: False):
         """Stream the output of a Popen process until the process exits. If the
         user sends CTRL+C, the process will be terminated.
 
@@ -379,19 +386,27 @@ class Subprocess:
             name=f"{label} output streamer",
             target=self._stream_output_thread,
             args=(popen_process,),
+            daemon=True,
         )
         try:
             output_streamer.start()
-            if stop_func:
-                while output_streamer.is_alive() and not stop_func():
-                    time.sleep(0.1)
-            else:
-                output_streamer.join()
+            # joining the thread is avoided due to demonstrated
+            # instability of thread interruption via CTRL+C (#809)
+            while not stop_func() and output_streamer.is_alive():
+                time.sleep(0.1)
         except KeyboardInterrupt:
-            pass  # allow CTRL+C to gracefully stop streaming
+            self.command.logger.info("Stopping...")
+            # allow time for CTRL+C to propagate to the child process
+            time.sleep(0.25)
         finally:
             self.cleanup(label, popen_process)
-            output_streamer.join()
+            streamer_deadline = time.time() + 3
+            while output_streamer.is_alive() and time.time() < streamer_deadline:
+                time.sleep(0.1)
+            if output_streamer.is_alive():
+                self.command.logger.error(
+                    "Log stream hasn't terminated; log output may be corrupted."
+                )
 
     def _stream_output_thread(self, popen_process):
         """Stream output for a Popen process in a Thread.
@@ -405,13 +420,7 @@ class Subprocess:
             if output_line:
                 self.command.logger.info(output_line)
             elif output_line == "":
-                # a return code will be available once the process returns one to the OS.
-                # by definition, that should mean the process has exited.
-                return_code = popen_process.poll()
-                # only return once all output has been read and the process has exited.
-                if return_code is not None:
-                    self._log_return_code(return_code)
-                    return
+                return
 
     def cleanup(self, label, popen_process):
         """Clean up after a Popen process, gracefully terminating if possible;
@@ -436,6 +445,12 @@ class Subprocess:
             f"    {' '.join(shlex.quote(str(arg)) for arg in args)}"
         )
 
+    def _log_cwd(self, cwd):
+        """Log the working directory for the  command being executed."""
+        effective_cwd = Path.cwd() if cwd is None else cwd
+        self.command.logger.debug("Working Directory:")
+        self.command.logger.debug(f"    {effective_cwd}")
+
     def _log_environment(self, overrides):
         """Log the environment variables overrides prior to command execution.
 
