@@ -2,29 +2,22 @@ import pytest
 
 
 def test_parse_options(base_command):
-    "Command line options are parsed if provided"
-    options = base_command.parse_options(
-        extra=(
-            '-x', 'wibble',
-            '-r', 'important'
-        )
-    )
+    """Command line options are parsed if provided."""
+    options = base_command.parse_options(extra=("-x", "wibble", "-r", "important"))
 
     assert options == {
-        'extra': "wibble",
-        'mystery':  None,
-        'required': "important",
+        "extra": "wibble",
+        "mystery": None,
+        "required": "important",
     }
     assert base_command.input.enabled
-    assert base_command.verbosity
+    assert base_command.logger.verbosity == 1
 
 
 def test_missing_option(base_command, capsys):
-    "If a required option isn't provided, an error is raised"
+    """If a required option isn't provided, an error is raised."""
     with pytest.raises(SystemExit) as excinfo:
-        base_command.parse_options(
-            extra=('-x', 'wibble')
-        )
+        base_command.parse_options(extra=("-x", "wibble"))
 
     # Error code for a missing required option
     assert excinfo.value.code == 2
@@ -34,11 +27,9 @@ def test_missing_option(base_command, capsys):
 
 
 def test_unknown_option(other_command, capsys):
-    "If an unknown command is provided, it rasises an error"
+    """If an unknown command is provided, it rasises an error."""
     with pytest.raises(SystemExit) as excinfo:
-        other_command.parse_options(
-            extra=('-y', 'because')
-        )
+        other_command.parse_options(extra=("-y", "because"))
 
     # Error code for a unknown option
     assert excinfo.value.code == 2
@@ -48,11 +39,9 @@ def test_unknown_option(other_command, capsys):
 
 
 def test_no_options(other_command, capsys):
-    "If a command doesn't define options, any option is an error"
+    """If a command doesn't define options, any option is an error."""
     with pytest.raises(SystemExit) as excinfo:
-        other_command.parse_options(
-            extra=('-x', 'wibble')
-        )
+        other_command.parse_options(extra=("-x", "wibble"))
 
     # Error code for a unknown option
     assert excinfo.value.code == 2
