@@ -73,9 +73,7 @@ class TrackingCreateCommand(DummyCreateCommand):
 
         self.actions = []
 
-    def verify_tools(
-        self,
-    ):
+    def verify_tools(self):
         super().verify_tools()
         self.actions.append(("verify",))
 
@@ -105,8 +103,9 @@ class TrackingCreateCommand(DummyCreateCommand):
 @pytest.fixture
 def create_command(tmp_path, mock_git):
     return DummyCreateCommand(
-        base_path=tmp_path,
-        home_path=tmp_path,
+        base_path=tmp_path / "project",
+        home_path=tmp_path / "home",
+        data_path=tmp_path / "data",
         git=mock_git,
     )
 
@@ -155,10 +154,16 @@ def bundle_path(myapp, tmp_path):
     # Return the bundle path for the app; however, as a side effect,
     # ensure that the app, app_packages and support target directories
     # exist, and the briefcase index file has been created.
-    bundle_path = tmp_path / "tester" / f"{myapp.app_name}.bundle"
+    bundle_path = tmp_path / "project" / "tester" / f"{myapp.app_name}.bundle"
     (bundle_path / "path" / "to" / "app").mkdir(parents=True, exist_ok=True)
-    (bundle_path / "path" / "to" / "app_packages").mkdir(parents=True, exist_ok=True)
     (bundle_path / "path" / "to" / "support").mkdir(parents=True, exist_ok=True)
+
+    return bundle_path
+
+
+@pytest.fixture
+def app_packages_path_index(bundle_path):
+    (bundle_path / "path" / "to" / "app_packages").mkdir(parents=True, exist_ok=True)
     with (bundle_path / "briefcase.toml").open("wb") as f:
         index = {
             "paths": {
@@ -169,7 +174,30 @@ def bundle_path(myapp, tmp_path):
         }
         tomli_w.dump(index, f)
 
-    return bundle_path
+
+@pytest.fixture
+def app_requirements_path_index(bundle_path):
+    with (bundle_path / "briefcase.toml").open("wb") as f:
+        index = {
+            "paths": {
+                "app_path": "path/to/app",
+                "app_requirements_path": "path/to/requirements.txt",
+                "support_path": "path/to/support",
+            }
+        }
+        tomli_w.dump(index, f)
+
+
+@pytest.fixture
+def no_support_path_index(bundle_path):
+    with (bundle_path / "briefcase.toml").open("wb") as f:
+        index = {
+            "paths": {
+                "app_path": "path/to/app",
+                "app_requirements_path": "path/to/requirements.txt",
+            }
+        }
+        tomli_w.dump(index, f)
 
 
 @pytest.fixture
@@ -177,6 +205,11 @@ def support_path(bundle_path):
     return bundle_path / "path" / "to" / "support"
 
 
+@pytest.fixture
+def app_requirements_path(bundle_path):
+    return bundle_path / "path" / "to" / "requirements.txt"
+
+
 @pytest.fixture
 def app_packages_path(bundle_path):
     return bundle_path / "path" / "to" / "app_packages"
