@@ -6,11 +6,12 @@ from tests.utils import DummyConsole
 
 
 class DummyNewCommand(NewCommand):
-    """
-    A dummy new command that doesn't actually do anything.
+    """A dummy new command that doesn't actually do anything.
+
     It only serves to track which actions would be performend.
     """
-    description = 'Dummy new command'
+
+    description = "Dummy new command"
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, apps=[], **kwargs)
@@ -20,13 +21,11 @@ class DummyNewCommand(NewCommand):
 
     def verify_tools(self):
         super().verify_tools()
-        self.actions.append(('verify',))
+        self.actions.append(("verify",))
 
     def new_app(self, **kwargs):
-        self.actions.append(('new', kwargs))
-        return full_options({
-            'new_state': 'done'
-        }, kwargs)
+        self.actions.append(("new", kwargs))
+        return full_options({"new_state": "done"}, kwargs)
 
 
 @pytest.fixture
