@@ -81,7 +81,7 @@ def test_emulator_path(mock_sdk, host_os, emulator_name):
 
 
 def test_avd_path(mock_sdk, tmp_path):
-    assert mock_sdk.avd_path == tmp_path / ".android" / "avd"
+    assert mock_sdk.avd_path == tmp_path / "home" / ".android" / "avd"
 
 
 def test_simple_env(mock_sdk, tmp_path):
