@@ -11,7 +11,8 @@ from tests.utils import DummyConsole
 @pytest.fixture
 def mock_sdk(tmp_path):
     command = MagicMock()
-    command.home_path = tmp_path
+    command.home_path = tmp_path / "home"
+    command.data_path = tmp_path / "data"
     command.subprocess = MagicMock()
     command.input = DummyConsole()
     command.logger = Log(verbosity=1)
