@@ -15,7 +15,8 @@ def mock_docker(tmp_path):
     command.base_path = tmp_path / "base"
     command.platform_path = tmp_path / "platform"
     command.bundle_path.return_value = tmp_path / "bundle"
-    command.dot_briefcase_path = tmp_path / ".briefcase"
+    command.data_path = tmp_path / "briefcase"
+    command.tools_path = command.data_path / "tools"
     command.docker_image_tag.return_value = "briefcase/com.example.myapp:py3.X"
     command.python_version_tag = "3.X"
     command.os.getuid.return_value = "37"
@@ -25,9 +26,13 @@ def mock_docker(tmp_path):
     command.subprocess._subprocess = MagicMock()
 
     proc = MagicMock()
+    # Mock return values for run
     proc.returncode = 3
     command.subprocess._subprocess.run.return_value = proc
 
+    # Mock return values for check_output
+    command.subprocess._subprocess.check_output.return_value = "goodbye\n"
+
     # Short circuit the process streamer
     wait_bar_streamer = MagicMock()
     wait_bar_streamer.stdout.readline.return_value = ""
