@@ -1,5 +1,6 @@
 import os
 import sys
+from pathlib import Path
 from unittest.mock import ANY
 
 import pytest
@@ -16,11 +17,11 @@ def test_simple_call(mock_docker, tmp_path, capsys):
         [
             "docker",
             "run",
-            "--tty",
             "--volume",
             f"{tmp_path / 'platform'}:/app:z",
             "--volume",
-            f"{tmp_path / '.briefcase'}:/home/brutus/.briefcase:z",
+            f"{tmp_path / 'briefcase'}:/home/brutus/.cache/briefcase:z",
+            "--rm",
             "briefcase/com.example.myapp:py3.X",
             "hello",
             "world",
@@ -31,20 +32,32 @@ def test_simple_call(mock_docker, tmp_path, capsys):
     assert capsys.readouterr().out == ""
 
 
-def test_simple_call_with_arg(mock_docker, tmp_path, capsys):
-    """Any extra keyword arguments are passed through as-is."""
+def test_call_with_arg_and_env(mock_docker, tmp_path, capsys):
+    """Extra keyword arguments are passed through as-is; env modifications are
+    converted."""
 
-    mock_docker.run(["hello", "world"], universal_newlines=True)
+    mock_docker.run(
+        ["hello", "world"],
+        env={
+            "MAGIC": "True",
+            "IMPORTANCE": "super high",
+        },
+        universal_newlines=True,
+    )
 
     mock_docker._subprocess._subprocess.run.assert_called_with(
         [
             "docker",
             "run",
-            "--tty",
             "--volume",
             f"{tmp_path / 'platform'}:/app:z",
             "--volume",
-            f"{tmp_path / '.briefcase'}:/home/brutus/.briefcase:z",
+            f"{tmp_path / 'briefcase'}:/home/brutus/.cache/briefcase:z",
+            "--rm",
+            "--env",
+            "MAGIC=True",
+            "--env",
+            "IMPORTANCE=super high",
             "briefcase/com.example.myapp:py3.X",
             "hello",
             "world",
@@ -55,20 +68,35 @@ def test_simple_call_with_arg(mock_docker, tmp_path, capsys):
     assert capsys.readouterr().out == ""
 
 
-def test_simple_call_with_path_arg(mock_docker, tmp_path, capsys):
-    """Path-based arguments are converted to strings and passed in as-is."""
+@pytest.mark.skipif(
+    sys.platform == "win32", reason="Windows paths aren't converted in Docker context"
+)
+def test_call_with_path_arg_and_env(mock_docker, tmp_path, capsys):
+    """Path-based arguments and environment are converted to strings and passed
+    in as-is."""
 
-    mock_docker.run(["hello", tmp_path / "location"], cwd=tmp_path / "cwd")
+    mock_docker.run(
+        ["hello", tmp_path / "location"],
+        env={
+            "MAGIC": "True",
+            "PATH": f"/somewhere/safe:{tmp_path / 'briefcase' / 'tools'}:{tmp_path / 'platform' / 'location'}",
+        },
+        cwd=tmp_path / "cwd",
+    )
 
     mock_docker._subprocess._subprocess.run.assert_called_with(
         [
             "docker",
             "run",
-            "--tty",
             "--volume",
             f"{tmp_path / 'platform'}:/app:z",
             "--volume",
-            f"{tmp_path / '.briefcase'}:/home/brutus/.briefcase:z",
+            f"{tmp_path / 'briefcase'}:/home/brutus/.cache/briefcase:z",
+            "--rm",
+            "--env",
+            "MAGIC=True",
+            "--env",
+            "PATH=/somewhere/safe:/home/brutus/.cache/briefcase/tools:/app/location",
             "briefcase/com.example.myapp:py3.X",
             "hello",
             os.fsdecode(tmp_path / "location"),
@@ -80,37 +108,6 @@ def test_simple_call_with_path_arg(mock_docker, tmp_path, capsys):
     assert capsys.readouterr().out == ""
 
 
-def test_simple_call_with_sys_executable_arg(
-    mock_docker, tmp_path, capsys, monkeypatch
-):
-    """Filepath arg that are same as sys.executable are replaced with
-    unqualified python[ver]"""
-
-    test_python_path = "/path/to/python"
-    monkeypatch.setattr("sys.executable", "/path/to/python")
-
-    mock_docker.run(["hello", test_python_path])
-
-    mock_docker._subprocess._subprocess.run.assert_called_with(
-        [
-            "docker",
-            "run",
-            "--tty",
-            "--volume",
-            f"{tmp_path / 'platform'}:/app:z",
-            "--volume",
-            f"{tmp_path / '.briefcase'}:/home/brutus/.briefcase:z",
-            "briefcase/com.example.myapp:py3.X",
-            "hello",
-            "python3.X",
-        ],
-        text=True,
-        encoding=ANY,
-    )
-
-    assert capsys.readouterr().out == ""
-
-
 @pytest.mark.skipif(
     sys.platform == "win32", reason="Windows paths aren't converted in Docker context"
 )
@@ -124,11 +121,11 @@ def test_simple_verbose_call(mock_docker, tmp_path, capsys):
         [
             "docker",
             "run",
-            "--tty",
             "--volume",
             f"{tmp_path / 'platform'}:/app:z",
             "--volume",
-            f"{tmp_path / '.briefcase'}:/home/brutus/.briefcase:z",
+            f"{tmp_path / 'briefcase'}:/home/brutus/.cache/briefcase:z",
+            "--rm",
             "briefcase/com.example.myapp:py3.X",
             "hello",
             "world",
@@ -139,10 +136,13 @@ def test_simple_verbose_call(mock_docker, tmp_path, capsys):
     assert capsys.readouterr().out == (
         "\n"
         ">>> Running Command:\n"
-        ">>>     docker run --tty "
+        ">>>     docker run "
         f"--volume {tmp_path / 'platform'}:/app:z "
-        f"--volume {tmp_path / '.briefcase'}:/home/brutus/.briefcase:z "
+        f"--volume {tmp_path / 'briefcase'}:/home/brutus/.cache/briefcase:z "
+        "--rm "
         "briefcase/com.example.myapp:py3.X "
         "hello world\n"
+        ">>> Working Directory:\n"
+        f">>>     {Path.cwd()}\n"
         ">>> Return code: 3\n"
     )
