@@ -1,7 +1,6 @@
 import os
 import shutil
 import sys
-
 from unittest.mock import MagicMock
 
 import pytest
@@ -11,7 +10,7 @@ from briefcase.exceptions import (
     BriefcaseCommandError,
     MissingToolError,
     NetworkFailure,
-    NonManagedToolError
+    NonManagedToolError,
 )
 from briefcase.integrations.java import JDK
 from tests.utils import FsPathMock
@@ -20,17 +19,18 @@ from tests.utils import FsPathMock
 @pytest.fixture
 def test_command(tmp_path):
     command = MagicMock()
-    command.host_os = 'Linux'
-    command.tools_path = tmp_path / 'tools'
+    command.host_os = "Linux"
+    command.tools_path = tmp_path / "tools"
 
     return command
 
 
 def test_non_managed_install(test_command, tmp_path, capsys):
-    "If the Java install points to a non-managed install, no upgrade is attempted"
+    """If the Java install points to a non-managed install, no upgrade is
+    attempted."""
 
     # Make the installation point to somewhere else.
-    jdk = JDK(test_command, java_home=tmp_path / 'other-jdk')
+    jdk = JDK(test_command, java_home=tmp_path / "other-jdk")
 
     # Attempt an upgrade. This will fail because the install is non-managed
     with pytest.raises(NonManagedToolError):
@@ -41,9 +41,9 @@ def test_non_managed_install(test_command, tmp_path, capsys):
 
 
 def test_non_existing_install(test_command, tmp_path):
-    "If there's no existing managed JDK install, upgrading is an error"
+    """If there's no existing managed JDK install, upgrading is an error."""
     # Create an SDK wrapper around a non-existing managed install
-    jdk = JDK(test_command, java_home=tmp_path / 'tools' / 'java')
+    jdk = JDK(test_command, java_home=tmp_path / "tools" / "java")
 
     with pytest.raises(MissingToolError):
         jdk.upgrade()
@@ -53,14 +53,16 @@ def test_non_existing_install(test_command, tmp_path):
 
 
 def test_existing_install(test_command, tmp_path):
-    "If there's an existing managed JDK install, it is deleted and redownloaded"
+    """If there's an existing managed JDK install, it is deleted and
+    redownloaded."""
     # Create a mock of a previously installed Java version.
-    java_home = tmp_path / 'tools' / 'java'
-    (java_home / 'bin').mkdir(parents=True)
+    java_home = tmp_path / "tools" / "java"
+    (java_home / "bin").mkdir(parents=True)
 
     # We actually need to delete the original java install
     def rmtree(path):
         shutil.rmtree(path)
+
     test_command.shutil.rmtree.side_effect = rmtree
 
     # Mock the cached download path.
@@ -74,7 +76,7 @@ def test_existing_install(test_command, tmp_path):
     test_command.download_url.return_value = archive
 
     # Create a directory to make it look like Java was downloaded and unpacked.
-    (tmp_path / 'tools' / 'jdk8u242-b08').mkdir(parents=True)
+    (tmp_path / "tools" / "jdk8u242-b08").mkdir(parents=True)
 
     # Create an SDK wrapper
     jdk = JDK(test_command, java_home=java_home)
@@ -88,32 +90,33 @@ def test_existing_install(test_command, tmp_path):
     # A download was initiated
     test_command.download_url.assert_called_with(
         url="https://github.com/AdoptOpenJDK/openjdk8-binaries/releases/download/"
-            "jdk8u242-b08/OpenJDK8U-jdk_x64_linux_hotspot_8u242b08.tar.gz",
-        download_path=tmp_path / 'tools',
+        "jdk8u242-b08/OpenJDK8U-jdk_x64_linux_hotspot_8u242b08.tar.gz",
+        download_path=tmp_path / "tools",
     )
 
     # The archive was unpacked.
     # TODO: Py3.6 compatibility; os.fsdecode not required in Py3.7
     test_command.shutil.unpack_archive.assert_called_with(
-        "/path/to/download.zip",
-        extract_dir=os.fsdecode(tmp_path / "tools")
+        "/path/to/download.zip", extract_dir=os.fsdecode(tmp_path / "tools")
     )
     # The original archive was deleted
     archive.unlink.assert_called_once_with()
 
 
 def test_macOS_existing_install(test_command, tmp_path):
-    "If there's an existing managed macOS JDK install, it is deleted and redownloaded"
+    """If there's an existing managed macOS JDK install, it is deleted and
+    redownloaded."""
     # Force mocking on macOS
-    test_command.host_os = 'Darwin'
+    test_command.host_os = "Darwin"
 
     # Create a mock of a previously installed Java version.
-    java_home = tmp_path / 'tools' / 'java' / 'Contents' / 'Home'
-    (java_home / 'bin').mkdir(parents=True)
+    java_home = tmp_path / "tools" / "java" / "Contents" / "Home"
+    (java_home / "bin").mkdir(parents=True)
 
     # We actually need to delete the original java install
     def rmtree(path):
         shutil.rmtree(path)
+
     test_command.shutil.rmtree.side_effect = rmtree
 
     # Mock the cached download path.
@@ -127,7 +130,7 @@ def test_macOS_existing_install(test_command, tmp_path):
     test_command.download_url.return_value = archive
 
     # Create a directory to make it look like Java was downloaded and unpacked.
-    (tmp_path / 'tools' / 'jdk8u242-b08').mkdir(parents=True)
+    (tmp_path / "tools" / "jdk8u242-b08").mkdir(parents=True)
 
     # Create an SDK wrapper
     jdk = JDK(test_command, java_home=java_home)
@@ -136,34 +139,35 @@ def test_macOS_existing_install(test_command, tmp_path):
     jdk.upgrade()
 
     # The old version has been deleted
-    test_command.shutil.rmtree.assert_called_with(tmp_path / 'tools' / 'java')
+    test_command.shutil.rmtree.assert_called_with(tmp_path / "tools" / "java")
 
     # A download was initiated
     test_command.download_url.assert_called_with(
         url="https://github.com/AdoptOpenJDK/openjdk8-binaries/releases/download/"
-            "jdk8u242-b08/OpenJDK8U-jdk_x64_mac_hotspot_8u242b08.tar.gz",
-        download_path=tmp_path / 'tools',
+        "jdk8u242-b08/OpenJDK8U-jdk_x64_mac_hotspot_8u242b08.tar.gz",
+        download_path=tmp_path / "tools",
     )
 
     # The archive was unpacked.
     # TODO: Py3.6 compatibility; os.fsdecode not required in Py3.7
     test_command.shutil.unpack_archive.assert_called_with(
-        "/path/to/download.zip",
-        extract_dir=os.fsdecode(tmp_path / "tools")
+        "/path/to/download.zip", extract_dir=os.fsdecode(tmp_path / "tools")
     )
     # The original archive was deleted
     archive.unlink.assert_called_once_with()
 
 
 def test_download_fail(test_command, tmp_path):
-    "If there's an existing managed JDK install, it is deleted and redownloaded"
+    """If there's an existing managed JDK install, it is deleted and
+    redownloaded."""
     # Create a mock of a previously installed Java version.
-    java_home = tmp_path / 'tools' / 'java'
-    (java_home / 'bin').mkdir(parents=True)
+    java_home = tmp_path / "tools" / "java"
+    (java_home / "bin").mkdir(parents=True)
 
     # We actually need to delete the original java install
     def rmtree(path):
         shutil.rmtree(path)
+
     test_command.shutil.rmtree.side_effect = rmtree
 
     # Mock a failure on download
@@ -182,8 +186,8 @@ def test_download_fail(test_command, tmp_path):
     # A download was initiated
     test_command.download_url.assert_called_with(
         url="https://github.com/AdoptOpenJDK/openjdk8-binaries/releases/download/"
-            "jdk8u242-b08/OpenJDK8U-jdk_x64_linux_hotspot_8u242b08.tar.gz",
-        download_path=tmp_path / 'tools',
+        "jdk8u242-b08/OpenJDK8U-jdk_x64_linux_hotspot_8u242b08.tar.gz",
+        download_path=tmp_path / "tools",
     )
 
     # No attempt was made to unpack the archive
@@ -191,14 +195,16 @@ def test_download_fail(test_command, tmp_path):
 
 
 def test_unpack_fail(test_command, tmp_path):
-    "If there's an existing managed JDK install, it is deleted and redownloaded"
+    """If there's an existing managed JDK install, it is deleted and
+    redownloaded."""
     # Create a mock of a previously installed Java version.
-    java_home = tmp_path / 'tools' / 'java'
-    (java_home / 'bin').mkdir(parents=True)
+    java_home = tmp_path / "tools" / "java"
+    (java_home / "bin").mkdir(parents=True)
 
     # We actually need to delete the original java install
     def rmtree(path):
         shutil.rmtree(path)
+
     test_command.shutil.rmtree.side_effect = rmtree
 
     # Mock the cached download path
@@ -227,15 +233,14 @@ def test_unpack_fail(test_command, tmp_path):
     # A download was initiated
     test_command.download_url.assert_called_with(
         url="https://github.com/AdoptOpenJDK/openjdk8-binaries/releases/download/"
-            "jdk8u242-b08/OpenJDK8U-jdk_x64_linux_hotspot_8u242b08.tar.gz",
-        download_path=tmp_path / 'tools',
+        "jdk8u242-b08/OpenJDK8U-jdk_x64_linux_hotspot_8u242b08.tar.gz",
+        download_path=tmp_path / "tools",
     )
 
     # The archive was unpacked.
     # TODO: Py3.6 compatibility; os.fsdecode not required in Py3.7
     test_command.shutil.unpack_archive.assert_called_with(
-        "/path/to/download.zip",
-        extract_dir=os.fsdecode(tmp_path / "tools")
+        "/path/to/download.zip", extract_dir=os.fsdecode(tmp_path / "tools")
     )
     # The original archive was not deleted
     assert archive.unlink.call_count == 0
