@@ -27,6 +27,7 @@ def create_mock_appimage(appimage_path: Path, mock_appimage_kind: str = "origina
         "corrupt": bytes.fromhex("%030x" % randrange(16**30)),
     }
 
+    appimage_path.parent.mkdir(parents=True, exist_ok=True)
     appimage_path.touch()
     with open(appimage_path, "w+b") as mock_appimage:
         if mock_appimage_kind in appimage_headers:
@@ -37,3 +38,27 @@ def create_mock_appimage(appimage_path: Path, mock_appimage_kind: str = "origina
         bytes_to_be_patched = mock_appimage.read(len(ELF_PATCH_ORIGINAL_BYTES))
 
     return bytes_to_be_patched
+
+
+def side_effect_create_mock_appimage(appimage_path):
+    """A test fixture side effect that creates an AppImage at the specified
+    path."""
+
+    def _side_effect(*args, **kwargs):
+        create_mock_appimage(appimage_path=appimage_path)
+        return "new-downloaded-file"
+
+    return _side_effect
+
+
+def side_effect_create_mock_tool(tool_path):
+    """A test fixture side effect that creates an sh file at the specified
+    path."""
+
+    def _side_effect(*args, **kwargs):
+        tool_path.parent.mkdir(parents=True)
+        with tool_path.open("w") as f:
+            f.write("I am a complete tool")
+        return "new-downloaded-file"
+
+    return _side_effect
