@@ -3,32 +3,31 @@ from unittest import mock
 
 import pytest
 
+from briefcase.console import Log
 from briefcase.exceptions import BriefcaseCommandError
-from briefcase.integrations.xcode import (
-    ensure_command_line_tools_are_installed
-)
+from briefcase.integrations.xcode import ensure_command_line_tools_are_installed
 
 
 def test_not_installed():
-    "If cmdline dev tools are not installed, raise an error."
+    """If cmdline dev tools are not installed, raise an error."""
     command = mock.MagicMock()
-
+    command.logger = Log()
     with pytest.raises(BriefcaseCommandError):
         ensure_command_line_tools_are_installed(command)
 
     # xcode-select was invoked
     command.subprocess.check_output.assert_called_once_with(
-        ['xcode-select', '--install'],
+        ["xcode-select", "--install"],
         stderr=subprocess.STDOUT,
     )
 
 
 def test_installed(capsys):
-    "If cmdline dev tools *are* installed, check passes without comment."
+    """If cmdline dev tools *are* installed, check passes without comment."""
     command = mock.MagicMock()
+    command.logger = Log()
     command.subprocess.check_output.side_effect = subprocess.CalledProcessError(
-        cmd=['xcode-select', '--install'],
-        returncode=1
+        cmd=["xcode-select", "--install"], returncode=1
     )
 
     # Check passes without an error...
@@ -36,7 +35,7 @@ def test_installed(capsys):
 
     # ... xcode-select was invoked
     command.subprocess.check_output.assert_called_once_with(
-        ['xcode-select', '--install'],
+        ["xcode-select", "--install"],
         stderr=subprocess.STDOUT,
     )
 
@@ -46,11 +45,11 @@ def test_installed(capsys):
 
 
 def test_unsure_if_installed(capsys):
-    "If xcode-select returns something odd, mention it but don't break."
+    """If xcode-select returns something odd, mention it but don't break."""
     command = mock.MagicMock()
+    command.logger = Log()
     command.subprocess.check_output.side_effect = subprocess.CalledProcessError(
-        cmd=['xcode-select', '--install'],
-        returncode=69
+        cmd=["xcode-select", "--install"], returncode=69
     )
 
     # Check passes without an error...
@@ -58,10 +57,10 @@ def test_unsure_if_installed(capsys):
 
     # ... xcode-select was invoked
     command.subprocess.check_output.assert_called_once_with(
-        ['xcode-select', '--install'],
+        ["xcode-select", "--install"],
         stderr=subprocess.STDOUT,
     )
 
     # ...but stdout contains a warning
     out = capsys.readouterr().out
-    assert '************' in out
+    assert "************" in out
