@@ -10,7 +10,7 @@ from briefcase.platforms.android.gradle import GradlePackageCommand
 @pytest.fixture
 def package_command(tmp_path, first_app_config):
     command = GradlePackageCommand(base_path=tmp_path / "base_path")
-    command.dot_briefcase_path = tmp_path / ".briefcase"
+    command.data_path = tmp_path / "briefcase"
     command.android_sdk = MagicMock()
     command.os = MagicMock()
     command.os.environ = {}
