@@ -55,8 +55,6 @@ def test_install_app_dependencies(first_app_config, tmp_path):
             "install",
             "--upgrade",
             "--no-user",
-            "--progress-bar",
-            "off",
             f"--target={tmp_path}/linux/appimage/First App/path/to/app_packages",
             "foo==1.2.3",
             "bar>=4.5",
@@ -101,8 +99,6 @@ def test_install_app_dependencies_no_docker(first_app_config, tmp_path):
             "install",
             "--upgrade",
             "--no-user",
-            "--progress-bar",
-            "off",
             f"--target={tmp_path}/linux/appimage/First App/path/to/app_packages",
             "foo==1.2.3",
             "bar>=4.5",
