@@ -8,7 +8,7 @@ from briefcase.platforms.macOS.xcode import macOSXcodeBuildCommand
 
 
 def test_build_app(first_app_config, tmp_path):
-    "An macOS App can be built"
+    """An macOS App can be built."""
     command = macOSXcodeBuildCommand(base_path=tmp_path)
 
     command.subprocess = mock.MagicMock()
@@ -16,25 +16,26 @@ def test_build_app(first_app_config, tmp_path):
 
     command.subprocess.run.assert_called_with(
         [
-            'xcodebuild',
-            '-project', tmp_path / 'macOS' / 'Xcode' / 'First App' / 'First App.xcodeproj',
-            '-quiet',
-            '-configuration', 'Release',
-            'build'
+            "xcodebuild",
+            "-project",
+            tmp_path / "macOS" / "Xcode" / "First App" / "First App.xcodeproj",
+            "-quiet",
+            "-configuration",
+            "Release",
+            "build",
         ],
-        check=True
+        check=True,
     )
 
 
 def test_build_app_failed(first_app_config, tmp_path):
-    "If xcodebuild fails, an error is raised."
+    """If xcodebuild fails, an error is raised."""
     command = macOSXcodeBuildCommand(base_path=tmp_path)
 
     # The subprocess.run() call will raise an error
     command.subprocess = mock.MagicMock()
     command.subprocess.run.side_effect = subprocess.CalledProcessError(
-        cmd=['xcodebuild', '...'],
-        returncode=1
+        cmd=["xcodebuild", "..."], returncode=1
     )
 
     with pytest.raises(BriefcaseCommandError):
@@ -42,11 +43,13 @@ def test_build_app_failed(first_app_config, tmp_path):
 
     command.subprocess.run.assert_called_with(
         [
-            'xcodebuild',
-            '-project', tmp_path / 'macOS' / 'Xcode' / 'First App' / 'First App.xcodeproj',
-            '-quiet',
-            '-configuration', 'Release',
-            'build'
+            "xcodebuild",
+            "-project",
+            tmp_path / "macOS" / "Xcode" / "First App" / "First App.xcodeproj",
+            "-quiet",
+            "-configuration",
+            "Release",
+            "build",
         ],
-        check=True
+        check=True,
     )
